@@ -376,7 +376,6 @@ gupnp_didl_lite_object_class_init (GUPnPDIDLLiteObjectClass *klass)
                                       GUPNP_TYPE_XML_DOC,
                                       G_PARAM_WRITABLE |
                                       G_PARAM_CONSTRUCT_ONLY |
-                                      G_PARAM_PRIVATE |
                                       G_PARAM_STATIC_NAME |
                                       G_PARAM_STATIC_NICK |
                                       G_PARAM_STATIC_BLURB));
@@ -1618,7 +1617,7 @@ gupnp_didl_lite_object_set_genre (GUPnPDIDLLiteObject *object,
         g_return_if_fail (GUPNP_IS_DIDL_LITE_OBJECT (object));
 
         xml_util_set_child (object->priv->xml_node,
-                            object->priv->dc_ns,
+                            object->priv->upnp_ns,
                             object->priv->xml_doc->doc,
                             "genre",
                             genre);
@@ -1699,7 +1698,7 @@ gupnp_didl_lite_object_set_album_art (GUPnPDIDLLiteObject *object,
                             (const unsigned char *)
                             "urn:schemas-dlna-org:metadata-2-0/",
                             (const unsigned char *) "dlna");
-        xmlNewNsProp (node,
+        xmlSetNsProp (node,
                       dlna_ns,
                       (const unsigned char *) "profileID",
                       (const unsigned char *) "JPEG_TN");
