@@ -57,22 +57,38 @@ static int
 compare_prop (const char *a, xmlAttr *attr)
 {
         const char *p;
-        const char *attr_name;
-        const char *parent_name;
+        char *parent_name;
+        char *attr_name;
+        int ret = -1;
 
-        attr_name = (const char *) attr->name;
-        parent_name = (const char *) attr->parent->name;
+        if (attr->ns != NULL)
+                attr_name = g_strjoin (":", attr->ns->prefix, attr->name, NULL);
+        else
+                attr_name = g_strdup ((const char *) attr->name);
+
+        if (attr->parent->ns != NULL)
+                parent_name = g_strjoin (":",
+                                         attr->parent->ns->prefix,
+                                         attr->parent->name,
+                                         NULL);
+        else
+                parent_name = g_strdup ((const char *) attr->parent->name);
 
         p = strstr (a, "@");
         if (p)
                 if (p == a)
                         /* Top-level property */
-                        return strcmp (a + 1, attr_name);
+                        ret = strcmp (a + 1, attr_name);
                 else
-                        return strncmp (a, parent_name, p - a) ||
-                               strcmp (p + 1, attr_name);
+                        ret = strncmp (a, parent_name, p - a) ||
+                              strcmp (p + 1, attr_name);
         else
-                return strcmp (a, attr_name);
+                ret = strcmp (a, attr_name);
+
+        g_free (attr_name);
+        g_free (parent_name);
+
+        return ret;
 }
 
 static gboolean
@@ -90,12 +106,16 @@ compare_node_name (const char *a, const char *b)
         const char *p;
         int len;
 
+        if (a[0] == '@')
+                /* Filer is for top-level property */
+                return -1;
+
         p = strstr (a, "@");
-        if (p != NULL) {
+        if (p != NULL)
+                /* Compare only the string before '@' */
                 len = p - a;
-        } else {
+        else
                 len = strlen (a);
-        }
 
         return strncmp (a, b, len);
 }
@@ -134,8 +154,6 @@ is_standard_prop (const char *name,
                 strcmp (name, "title") == 0) ||
                (g_strcmp0 (namespace, "upnp") == 0 &&
                 strcmp (name, "class") == 0) ||
-               (g_strcmp0 (parent_name, "albumArtURI") == 0 &&
-                strcmp (name, "profileID") == 0) ||
                (g_strcmp0 (parent_name, "res") == 0 &&
                 strcmp (name, "protocolInfo") == 0);
 }
